function Update()
	-- If in the current month or if browsing and Month changes to that month, set to Real Time
	if (Time.stats.inmonth and Time.show.month ~= Time.curr.month) or ((not Time.stats.inmonth) and Time.show.month == Time.curr.month and Time.show.year == Time.curr.year) then
		Move()
	end
	
	if Time.show.month ~= Time.old.month or Time.show.year ~= Time.old.year then -- Recalculate and Redraw if Month and/or Year changes
		Time.old = {month = Time.show.month, year = Time.show.year, day = Time.curr.day}
		String = Draw()
	elseif Time.curr.day ~= Time.old.day then -- Redraw if Today changes
		Time.old.day = Time.curr.day
		String = Draw()
	end

	return String
end -- Update

Time = { -- Used to store and call date functions and statistics
	curr = setmetatable({}, {__index = function(_, index) return os.date('*t')[index] end,}),
	old = {day = 0, month = 0, year = 0,},
	show = {month = 0, year = 0,},
	stats = setmetatable({inmonth = true,}, {__index = function(_, index)
		local tstart = os.time{day = 1, month = Time.show.month, year = Time.show.year, isdst = false,}
		local nstart = os.time{day = 1, month = (Time.show.month % 12 + 1), year = (Time.show.year + (Time.show.month == 12 and 1 or 0)), isdst = false,}
		
		return ({
			clength = ((nstart - tstart) / 86400),
			plength = tonumber(os.date('%d', tstart - 86400)),
			startday = tonumber(os.date('%w', tstart)),
		})[index]
	end,}),
} -- Time

function Draw() -- Sets all meter properties and calculates days	
	local StartDay = Time.stats.startday
	local MonthLength = Time.stats.clength
	local PreviousMonth = Time.stats.plength
	local current = Time.stats.inmonth and Time.curr.day or 0

	os.setlocale('', 'time')
	local lines = {
		'<' .. center(os.date('%B %Y', os.time{month = Time.show.month, day = 1, year = Time.show.year, isdst = false,}), 26) .. '>',
		'   S   M   T   W   T   F   S',
	}

	for i = 0, 5 do
		local tbl = {}
		for j = 1, 7 do
			local day = i * 7 + j - StartDay
			if day < 1 then
				day = PreviousMonth + day
			elseif day > MonthLength then
				day = day - MonthLength
			elseif day == current then
				day = '|' .. day
			end
			table.insert(tbl, string.format('%4s', day))
		end
		table.insert(lines, table.concat(tbl))
	end

	return table.concat(lines, '\n')
end -- Draw

function center(line, num)
	local length = line:len()
	local first = math.floor((num - length) / 2)
	return string.rep(' ', first) .. line .. string.rep(' ', num - length - first)
end -- center

function Move(value) -- Move calendar through the months
	if value then assert(tonumber(value), string.format('Move: input must be a number. Received %s instead.', type(value))) end
	if not value then
		Time.show = Time.curr
	elseif math.ceil(value) == value then
		local mvalue = Time.show.month + value - (math.modf(value / 12)) * 12
		local mchange = value < 0 and (mvalue < 1 and 12 or 0) or (mvalue > 12 and -12 or 0)
		Time.show = {month = (mvalue + mchange), year = (Time.show.year + (math.modf(value / 12)) - mchange / 12),}
	end

	Time.stats.inmonth = Time.show.month == Time.curr.month and Time.show.year == Time.curr.year
	SKIN:Bang('!Update')
end -- Move

function GetDate(x, y, width, height)
	local col = math.ceil(x / (width / 7))
	local row = math.ceil(y / (height / 8))
	if row == 1 and col == 1 then
		Move(-1)
	elseif row == 1 and col == 7 then
		Move(1)
	elseif row > 2 then
		local Stamp = os.time{month = Time.show.month, year = Time.show.year, day = 1, isdst = false,}
		local day = (row - 3) * 7 + (col - 1) - Time.stats.startday
		local temp = os.date('*t', Stamp + day * 86400)
		local bang = SELF:GetOption('Bang'):gsub('%$([^$]+)%$', function(word) return temp[word:lower()] end)
		SKIN:Bang(bang)
	end
end -- GetDate